# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.artifact import Artifact
from keplar_api.models.artifact_version_group import ArtifactVersionGroup
from keplar_api.models.attribute_kind_group import AttributeKindGroup
from keplar_api.models.chat_session import ChatSession
from keplar_api.models.invite_with_analytics import InviteWithAnalytics
from keplar_api.models.moderator import Moderator
from keplar_api.models.project_analysis import ProjectAnalysis
from keplar_api.models.project_config import ProjectConfig
from keplar_api.models.project_conversation_config import ProjectConversationConfig
from keplar_api.models.project_file import ProjectFile
from keplar_api.models.project_status import ProjectStatus
from keplar_api.models.thread import Thread
from keplar_api.models.user import User
from keplar_api.models.workspace import Workspace
from typing import Optional, Set
from typing_extensions import Self

class ProjectWithAnalytics(BaseModel):
    """
    ProjectWithAnalytics
    """ # noqa: E501
    id: StrictStr
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    name: StrictStr
    description: Optional[StrictStr] = None
    status: ProjectStatus
    created_by_id: StrictStr = Field(alias="createdById")
    workspace_id: StrictStr = Field(alias="workspaceId")
    moderator_id: StrictStr = Field(alias="moderatorId")
    config: ProjectConfig
    conversation_config: ProjectConversationConfig = Field(alias="conversationConfig")
    analysis: Optional[ProjectAnalysis] = None
    created_by: Optional[User] = Field(default=None, alias="createdBy")
    workspace: Optional[Workspace] = None
    moderator: Optional[Moderator] = None
    invites: List[InviteWithAnalytics]
    chat_sessions: Optional[List[ChatSession]] = Field(default=None, alias="chatSessions")
    project_files: Optional[List[ProjectFile]] = Field(default=None, alias="projectFiles")
    threads: Optional[List[Thread]] = None
    attribute_kind_group: Optional[List[AttributeKindGroup]] = Field(default=None, alias="AttributeKindGroup")
    artifacts: Optional[List[Artifact]] = None
    artifact_version_group: Optional[List[ArtifactVersionGroup]] = Field(default=None, alias="ArtifactVersionGroup")
    __properties: ClassVar[List[str]] = ["id", "createdAt", "updatedAt", "name", "description", "status", "createdById", "workspaceId", "moderatorId", "config", "conversationConfig", "analysis", "createdBy", "workspace", "moderator", "invites", "chatSessions", "projectFiles", "threads", "AttributeKindGroup", "artifacts", "ArtifactVersionGroup"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ProjectWithAnalytics from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of config
        if self.config:
            _dict['config'] = self.config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of conversation_config
        if self.conversation_config:
            _dict['conversationConfig'] = self.conversation_config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of analysis
        if self.analysis:
            _dict['analysis'] = self.analysis.to_dict()
        # override the default output from pydantic by calling `to_dict()` of created_by
        if self.created_by:
            _dict['createdBy'] = self.created_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of workspace
        if self.workspace:
            _dict['workspace'] = self.workspace.to_dict()
        # override the default output from pydantic by calling `to_dict()` of moderator
        if self.moderator:
            _dict['moderator'] = self.moderator.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in invites (list)
        _items = []
        if self.invites:
            for _item_invites in self.invites:
                if _item_invites:
                    _items.append(_item_invites.to_dict())
            _dict['invites'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in chat_sessions (list)
        _items = []
        if self.chat_sessions:
            for _item_chat_sessions in self.chat_sessions:
                if _item_chat_sessions:
                    _items.append(_item_chat_sessions.to_dict())
            _dict['chatSessions'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in project_files (list)
        _items = []
        if self.project_files:
            for _item_project_files in self.project_files:
                if _item_project_files:
                    _items.append(_item_project_files.to_dict())
            _dict['projectFiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in threads (list)
        _items = []
        if self.threads:
            for _item_threads in self.threads:
                if _item_threads:
                    _items.append(_item_threads.to_dict())
            _dict['threads'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in attribute_kind_group (list)
        _items = []
        if self.attribute_kind_group:
            for _item_attribute_kind_group in self.attribute_kind_group:
                if _item_attribute_kind_group:
                    _items.append(_item_attribute_kind_group.to_dict())
            _dict['AttributeKindGroup'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in artifacts (list)
        _items = []
        if self.artifacts:
            for _item_artifacts in self.artifacts:
                if _item_artifacts:
                    _items.append(_item_artifacts.to_dict())
            _dict['artifacts'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in artifact_version_group (list)
        _items = []
        if self.artifact_version_group:
            for _item_artifact_version_group in self.artifact_version_group:
                if _item_artifact_version_group:
                    _items.append(_item_artifact_version_group.to_dict())
            _dict['ArtifactVersionGroup'] = _items
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if analysis (nullable) is None
        # and model_fields_set contains the field
        if self.analysis is None and "analysis" in self.model_fields_set:
            _dict['analysis'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ProjectWithAnalytics from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "status": obj.get("status"),
            "createdById": obj.get("createdById"),
            "workspaceId": obj.get("workspaceId"),
            "moderatorId": obj.get("moderatorId"),
            "config": ProjectConfig.from_dict(obj["config"]) if obj.get("config") is not None else None,
            "conversationConfig": ProjectConversationConfig.from_dict(obj["conversationConfig"]) if obj.get("conversationConfig") is not None else None,
            "analysis": ProjectAnalysis.from_dict(obj["analysis"]) if obj.get("analysis") is not None else None,
            "createdBy": User.from_dict(obj["createdBy"]) if obj.get("createdBy") is not None else None,
            "workspace": Workspace.from_dict(obj["workspace"]) if obj.get("workspace") is not None else None,
            "moderator": Moderator.from_dict(obj["moderator"]) if obj.get("moderator") is not None else None,
            "invites": [InviteWithAnalytics.from_dict(_item) for _item in obj["invites"]] if obj.get("invites") is not None else None,
            "chatSessions": [ChatSession.from_dict(_item) for _item in obj["chatSessions"]] if obj.get("chatSessions") is not None else None,
            "projectFiles": [ProjectFile.from_dict(_item) for _item in obj["projectFiles"]] if obj.get("projectFiles") is not None else None,
            "threads": [Thread.from_dict(_item) for _item in obj["threads"]] if obj.get("threads") is not None else None,
            "AttributeKindGroup": [AttributeKindGroup.from_dict(_item) for _item in obj["AttributeKindGroup"]] if obj.get("AttributeKindGroup") is not None else None,
            "artifacts": [Artifact.from_dict(_item) for _item in obj["artifacts"]] if obj.get("artifacts") is not None else None,
            "ArtifactVersionGroup": [ArtifactVersionGroup.from_dict(_item) for _item in obj["ArtifactVersionGroup"]] if obj.get("ArtifactVersionGroup") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.attribute_stats_schema_inner import AttributeStatsSchemaInner

class TestAttributeStatsSchemaInner(unittest.TestCase):
    """AttributeStatsSchemaInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AttributeStatsSchemaInner:
        """Test AttributeStatsSchemaInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AttributeStatsSchemaInner`
        """
        model = AttributeStatsSchemaInner()
        if include_optional:
            return AttributeStatsSchemaInner(
                kind = keplar_api.models.attribute_stats_schema_inner_kind.AttributeStatsSchema_inner_kind(
                    id = '', 
                    label = '', 
                    description = '', 
                    category = '', 
                    value_kind = 'single', ),
                group = keplar_api.models.attribute_stats_schema_inner_group.AttributeStatsSchema_inner_group(
                    id = '', 
                    purpose = 'screener_response', ),
                values = [
                    keplar_api.models.attribute_stats_schema_inner_values_inner.AttributeStatsSchema_inner_values_inner(
                        id = '', 
                        value = '', 
                        count = 1.337, 
                        total_count = 1.337, )
                    ]
            )
        else:
            return AttributeStatsSchemaInner(
                kind = keplar_api.models.attribute_stats_schema_inner_kind.AttributeStatsSchema_inner_kind(
                    id = '', 
                    label = '', 
                    description = '', 
                    category = '', 
                    value_kind = 'single', ),
                values = [
                    keplar_api.models.attribute_stats_schema_inner_values_inner.AttributeStatsSchema_inner_values_inner(
                        id = '', 
                        value = '', 
                        count = 1.337, 
                        total_count = 1.337, )
                    ],
        )
        """

    def testAttributeStatsSchemaInner(self):
        """Test AttributeStatsSchemaInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.org_data import OrgData
from typing import Optional, Set
from typing_extensions import Self

class Org(BaseModel):
    """
    Org
    """ # noqa: E501
    id: StrictStr
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    name: StrictStr
    domain: StrictStr
    data: Optional[OrgData] = None
    default_workspace_id: Optional[StrictStr] = Field(default=None, alias="defaultWorkspaceId")
    users: Optional[List[User]] = None
    default_workspace: Optional[Workspace] = Field(default=None, alias="defaultWorkspace")
    __properties: ClassVar[List[str]] = ["id", "createdAt", "updatedAt", "name", "domain", "data", "defaultWorkspaceId", "users", "defaultWorkspace"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Org from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of data
        if self.data:
            _dict['data'] = self.data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in users (list)
        _items = []
        if self.users:
            for _item_users in self.users:
                if _item_users:
                    _items.append(_item_users.to_dict())
            _dict['users'] = _items
        # override the default output from pydantic by calling `to_dict()` of default_workspace
        if self.default_workspace:
            _dict['defaultWorkspace'] = self.default_workspace.to_dict()
        # set to None if data (nullable) is None
        # and model_fields_set contains the field
        if self.data is None and "data" in self.model_fields_set:
            _dict['data'] = None

        # set to None if default_workspace_id (nullable) is None
        # and model_fields_set contains the field
        if self.default_workspace_id is None and "default_workspace_id" in self.model_fields_set:
            _dict['defaultWorkspaceId'] = None

        # set to None if default_workspace (nullable) is None
        # and model_fields_set contains the field
        if self.default_workspace is None and "default_workspace" in self.model_fields_set:
            _dict['defaultWorkspace'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Org from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "name": obj.get("name"),
            "domain": obj.get("domain"),
            "data": OrgData.from_dict(obj["data"]) if obj.get("data") is not None else None,
            "defaultWorkspaceId": obj.get("defaultWorkspaceId"),
            "users": [User.from_dict(_item) for _item in obj["users"]] if obj.get("users") is not None else None,
            "defaultWorkspace": Workspace.from_dict(obj["defaultWorkspace"]) if obj.get("defaultWorkspace") is not None else None
        })
        return _obj

from keplar_api.models.user import User
from keplar_api.models.workspace import Workspace
# TODO: Rewrite to not use raise_errors
Org.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.file_mime_type import FileMimeType
from typing import Optional, Set
from typing_extensions import Self

class File(BaseModel):
    """
    File
    """ # noqa: E501
    id: StrictStr
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    filename: StrictStr
    display_name: Optional[StrictStr] = Field(default=None, alias="displayName")
    mime_type: FileMimeType = Field(alias="mimeType")
    size: StrictStr
    bucket_name: StrictStr = Field(alias="bucketName")
    gcs_path: StrictStr = Field(alias="gcsPath")
    gcs_generation: Optional[StrictStr] = Field(default=None, alias="gcsGeneration")
    uploaded_by_id: StrictStr = Field(alias="uploadedById")
    workspace_id: StrictStr = Field(alias="workspaceId")
    description: Optional[StrictStr] = None
    metadata: Optional[Dict[str, Any]] = None
    is_public: StrictBool = Field(alias="isPublic")
    expires_at: Optional[datetime] = Field(default=None, alias="expiresAt")
    public_url: Optional[StrictStr] = Field(default=None, alias="publicUrl")
    public_url_expires_at: Optional[datetime] = Field(default=None, alias="publicUrlExpiresAt")
    uploaded_by: Optional[User] = Field(default=None, alias="uploadedBy")
    workspace: Optional[Workspace] = None
    project_files: Optional[List[ProjectFile]] = Field(default=None, alias="projectFiles")
    thread_files: Optional[List[ThreadFile]] = Field(default=None, alias="threadFiles")
    __properties: ClassVar[List[str]] = ["id", "createdAt", "updatedAt", "filename", "displayName", "mimeType", "size", "bucketName", "gcsPath", "gcsGeneration", "uploadedById", "workspaceId", "description", "metadata", "isPublic", "expiresAt", "publicUrl", "publicUrlExpiresAt", "uploadedBy", "workspace", "projectFiles", "threadFiles"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of File from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of uploaded_by
        if self.uploaded_by:
            _dict['uploadedBy'] = self.uploaded_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of workspace
        if self.workspace:
            _dict['workspace'] = self.workspace.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in project_files (list)
        _items = []
        if self.project_files:
            for _item_project_files in self.project_files:
                if _item_project_files:
                    _items.append(_item_project_files.to_dict())
            _dict['projectFiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in thread_files (list)
        _items = []
        if self.thread_files:
            for _item_thread_files in self.thread_files:
                if _item_thread_files:
                    _items.append(_item_thread_files.to_dict())
            _dict['threadFiles'] = _items
        # set to None if display_name (nullable) is None
        # and model_fields_set contains the field
        if self.display_name is None and "display_name" in self.model_fields_set:
            _dict['displayName'] = None

        # set to None if gcs_generation (nullable) is None
        # and model_fields_set contains the field
        if self.gcs_generation is None and "gcs_generation" in self.model_fields_set:
            _dict['gcsGeneration'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        # set to None if expires_at (nullable) is None
        # and model_fields_set contains the field
        if self.expires_at is None and "expires_at" in self.model_fields_set:
            _dict['expiresAt'] = None

        # set to None if public_url (nullable) is None
        # and model_fields_set contains the field
        if self.public_url is None and "public_url" in self.model_fields_set:
            _dict['publicUrl'] = None

        # set to None if public_url_expires_at (nullable) is None
        # and model_fields_set contains the field
        if self.public_url_expires_at is None and "public_url_expires_at" in self.model_fields_set:
            _dict['publicUrlExpiresAt'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of File from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "filename": obj.get("filename"),
            "displayName": obj.get("displayName"),
            "mimeType": obj.get("mimeType"),
            "size": obj.get("size"),
            "bucketName": obj.get("bucketName"),
            "gcsPath": obj.get("gcsPath"),
            "gcsGeneration": obj.get("gcsGeneration"),
            "uploadedById": obj.get("uploadedById"),
            "workspaceId": obj.get("workspaceId"),
            "description": obj.get("description"),
            "metadata": obj.get("metadata"),
            "isPublic": obj.get("isPublic"),
            "expiresAt": obj.get("expiresAt"),
            "publicUrl": obj.get("publicUrl"),
            "publicUrlExpiresAt": obj.get("publicUrlExpiresAt"),
            "uploadedBy": User.from_dict(obj["uploadedBy"]) if obj.get("uploadedBy") is not None else None,
            "workspace": Workspace.from_dict(obj["workspace"]) if obj.get("workspace") is not None else None,
            "projectFiles": [ProjectFile.from_dict(_item) for _item in obj["projectFiles"]] if obj.get("projectFiles") is not None else None,
            "threadFiles": [ThreadFile.from_dict(_item) for _item in obj["threadFiles"]] if obj.get("threadFiles") is not None else None
        })
        return _obj

from keplar_api.models.project_file import ProjectFile
from keplar_api.models.thread_file import ThreadFile
from keplar_api.models.user import User
from keplar_api.models.workspace import Workspace
# TODO: Rewrite to not use raise_errors
File.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.project_summary_with_analytics import ProjectSummaryWithAnalytics

class TestProjectSummaryWithAnalytics(unittest.TestCase):
    """ProjectSummaryWithAnalytics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProjectSummaryWithAnalytics:
        """Test ProjectSummaryWithAnalytics
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProjectSummaryWithAnalytics`
        """
        model = ProjectSummaryWithAnalytics()
        if include_optional:
            return ProjectSummaryWithAnalytics(
                id = '',
                name = '',
                description = '',
                status = 'ACTIVE',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                config = keplar_api.models.project_config.ProjectConfig(
                    project_kind = 'custom', 
                    prompt_variables = {
                        'key' : null
                        }, 
                    learning_plan = '', 
                    brief = keplar_api.models.project_brief.ProjectBrief(
                        title = '', 
                        objective = '', 
                        learning_goals = '', 
                        key_questions = '', 
                        conversation_flow = [
                            ''
                            ], 
                        rules = [
                            ''
                            ], 
                        assets = [
                            ''
                            ], ), 
                    current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                        doc = keplar_api.models.brief_document.BriefDocument(
                            type = 'doc', 
                            content = [
                                keplar_api.models.content_node.ContentNode()
                                ], ), 
                        version = 1.337, 
                        created_at = '', 
                        updated_at = '', ), 
                    brief_document = '', 
                    screener_questions = [
                        keplar_api.models.screener_question.ScreenerQuestion()
                        ], 
                    audience_settings = keplar_api.models.project_audience.ProjectAudience(
                        sample_size = 1.337, 
                        invite_title = '', 
                        invite_description = '', 
                        participants = [
                            keplar_api.models.participant_create.ParticipantCreate(
                                id = '', 
                                name = '', 
                                email = '', 
                                phone_number = '01234', 
                                data = keplar_api.models.data.data(), )
                            ], 
                        panel_settings = keplar_api.models.panel_settings.PanelSettings(
                            respondent_attributes = [
                                keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                    qualifications = [
                                        keplar_api.models.panel_qualification.PanelQualification(
                                            allowed_option_ids = [
                                                null
                                                ], 
                                            question_id = 1.337, )
                                        ], 
                                    quota = 1.337, 
                                    quota_name = '', )
                                ], 
                            country_code = '', 
                            language_code = '', 
                            length_of_interview = 1.337, 
                            incidence_rate = 1.337, 
                            compensation = 1.337, ), 
                        use_public_link = True, ), ),
                invites = [
                    keplar_api.models.invite_with_analytics.InviteWithAnalytics()
                    ]
            )
        else:
            return ProjectSummaryWithAnalytics(
                id = '',
                name = '',
                status = 'ACTIVE',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                config = keplar_api.models.project_config.ProjectConfig(
                    project_kind = 'custom', 
                    prompt_variables = {
                        'key' : null
                        }, 
                    learning_plan = '', 
                    brief = keplar_api.models.project_brief.ProjectBrief(
                        title = '', 
                        objective = '', 
                        learning_goals = '', 
                        key_questions = '', 
                        conversation_flow = [
                            ''
                            ], 
                        rules = [
                            ''
                            ], 
                        assets = [
                            ''
                            ], ), 
                    current_brief_version = keplar_api.models.brief_document_version.BriefDocumentVersion(
                        doc = keplar_api.models.brief_document.BriefDocument(
                            type = 'doc', 
                            content = [
                                keplar_api.models.content_node.ContentNode()
                                ], ), 
                        version = 1.337, 
                        created_at = '', 
                        updated_at = '', ), 
                    brief_document = '', 
                    screener_questions = [
                        keplar_api.models.screener_question.ScreenerQuestion()
                        ], 
                    audience_settings = keplar_api.models.project_audience.ProjectAudience(
                        sample_size = 1.337, 
                        invite_title = '', 
                        invite_description = '', 
                        participants = [
                            keplar_api.models.participant_create.ParticipantCreate(
                                id = '', 
                                name = '', 
                                email = '', 
                                phone_number = '01234', 
                                data = keplar_api.models.data.data(), )
                            ], 
                        panel_settings = keplar_api.models.panel_settings.PanelSettings(
                            respondent_attributes = [
                                keplar_api.models.panel_respondent_attribute.PanelRespondentAttribute(
                                    qualifications = [
                                        keplar_api.models.panel_qualification.PanelQualification(
                                            allowed_option_ids = [
                                                null
                                                ], 
                                            question_id = 1.337, )
                                        ], 
                                    quota = 1.337, 
                                    quota_name = '', )
                                ], 
                            country_code = '', 
                            language_code = '', 
                            length_of_interview = 1.337, 
                            incidence_rate = 1.337, 
                            compensation = 1.337, ), 
                        use_public_link = True, ), ),
                invites = [
                    keplar_api.models.invite_with_analytics.InviteWithAnalytics()
                    ],
        )
        """

    def testProjectSummaryWithAnalytics(self):
        """Test ProjectSummaryWithAnalytics"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.invite_response_evaluation_enum import InviteResponseEvaluationEnum
from typing import Optional, Set
from typing_extensions import Self

class InviteResponseEvaluationMetadata(BaseModel):
    """
    InviteResponseEvaluationMetadata
    """ # noqa: E501
    created_at: datetime = Field(alias="createdAt")
    original_evaluation: Optional[InviteResponseEvaluationEnum] = Field(default=None, alias="originalEvaluation")
    previous_evaluation: Optional[InviteResponseEvaluationEnum] = Field(default=None, alias="previousEvaluation")
    created_by: Optional[StrictStr] = Field(default=None, alias="createdBy")
    notes: Optional[StrictStr] = None
    transcript_quality: Optional[StrictStr] = Field(default=None, alias="transcriptQuality")
    __properties: ClassVar[List[str]] = ["createdAt", "originalEvaluation", "previousEvaluation", "createdBy", "notes", "transcriptQuality"]

    @field_validator('transcript_quality')
    def transcript_quality_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['HIGH', 'MEDIUM', 'LOW']):
            raise ValueError("must be one of enum values ('HIGH', 'MEDIUM', 'LOW')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of InviteResponseEvaluationMetadata from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if original_evaluation (nullable) is None
        # and model_fields_set contains the field
        if self.original_evaluation is None and "original_evaluation" in self.model_fields_set:
            _dict['originalEvaluation'] = None

        # set to None if previous_evaluation (nullable) is None
        # and model_fields_set contains the field
        if self.previous_evaluation is None and "previous_evaluation" in self.model_fields_set:
            _dict['previousEvaluation'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of InviteResponseEvaluationMetadata from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "createdAt": obj.get("createdAt"),
            "originalEvaluation": obj.get("originalEvaluation"),
            "previousEvaluation": obj.get("previousEvaluation"),
            "createdBy": obj.get("createdBy"),
            "notes": obj.get("notes"),
            "transcriptQuality": obj.get("transcriptQuality")
        })
        return _obj





# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.join_code_invite302_response_settings import JoinCodeInvite302ResponseSettings

class TestJoinCodeInvite302ResponseSettings(unittest.TestCase):
    """JoinCodeInvite302ResponseSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JoinCodeInvite302ResponseSettings:
        """Test JoinCodeInvite302ResponseSettings
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JoinCodeInvite302ResponseSettings`
        """
        model = JoinCodeInvite302ResponseSettings()
        if include_optional:
            return JoinCodeInvite302ResponseSettings(
                max_duration_seconds = 1.337,
                screener_questions = [
                    null
                    ],
                files = [
                    keplar_api.models.project_file_public.ProjectFilePublic(
                        file = keplar_api.models.project_file_public_file.ProjectFilePublic_file(
                            description = '', 
                            mime_type = 'image/jpeg', 
                            public_url = '', 
                            public_url_expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        description = '', 
                        metadata = keplar_api.models.project_file_metadata.ProjectFileMetadata(
                            name = '', 
                            prompt = '', 
                            image_description = '', ), )
                    ],
                language = 'en',
                video_recording = keplar_api.models.video_recording_settings.VideoRecordingSettings(
                    enabled = True, 
                    include_audio = True, )
            )
        else:
            return JoinCodeInvite302ResponseSettings(
                max_duration_seconds = 1.337,
        )
        """

    def testJoinCodeInvite302ResponseSettings(self):
        """Test JoinCodeInvite302ResponseSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.screener_question_choose_multiple_public import ScreenerQuestionChooseMultiplePublic

class TestScreenerQuestionChooseMultiplePublic(unittest.TestCase):
    """ScreenerQuestionChooseMultiplePublic unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ScreenerQuestionChooseMultiplePublic:
        """Test ScreenerQuestionChooseMultiplePublic
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ScreenerQuestionChooseMultiplePublic`
        """
        model = ScreenerQuestionChooseMultiplePublic()
        if include_optional:
            return ScreenerQuestionChooseMultiplePublic(
                type = 'chooseMultiple',
                question = '',
                image_file_id = '',
                options = {
                    'key' : keplar_api.models.screener_question_choose_multiple_options_value.ScreenerQuestionChooseMultiple_options_value(
                        option_text = '', 
                        option_kind = 'neutral', 
                        index = 0, )
                    },
                randomize_order = True,
                show_select_all_of_above = True,
                show_select_none_of_above = True,
                image_url = ''
            )
        else:
            return ScreenerQuestionChooseMultiplePublic(
                type = 'chooseMultiple',
                question = '',
                options = {
                    'key' : keplar_api.models.screener_question_choose_multiple_options_value.ScreenerQuestionChooseMultiple_options_value(
                        option_text = '', 
                        option_kind = 'neutral', 
                        index = 0, )
                    },
                show_select_all_of_above = True,
                show_select_none_of_above = True,
        )
        """

    def testScreenerQuestionChooseMultiplePublic(self):
        """Test ScreenerQuestionChooseMultiplePublic"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.get_orgs200_response_items_inner import GetOrgs200ResponseItemsInner

class TestGetOrgs200ResponseItemsInner(unittest.TestCase):
    """GetOrgs200ResponseItemsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetOrgs200ResponseItemsInner:
        """Test GetOrgs200ResponseItemsInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetOrgs200ResponseItemsInner`
        """
        model = GetOrgs200ResponseItemsInner()
        if include_optional:
            return GetOrgs200ResponseItemsInner(
                id = '',
                name = '',
                domain = '',
                is2_fa_enabled = True,
                default_workspace_id = '',
                default_workspace = keplar_api.models.get_orgs_200_response_items_inner_default_workspace.getOrgs_200_response_items_inner_defaultWorkspace(
                    id = '', 
                    name = '', ),
                stats = keplar_api.models.get_orgs_200_response_items_inner_stats.getOrgs_200_response_items_inner_stats(
                    total_projects = 1.337, 
                    total_responses_completed = 1.337, 
                    total_responses = 1.337, 
                    total_members = 1.337, 
                    last_activity_at = '', ),
                created_at = '',
                updated_at = ''
            )
        else:
            return GetOrgs200ResponseItemsInner(
                id = '',
                name = '',
                domain = '',
                is2_fa_enabled = True,
                default_workspace_id = '',
                default_workspace = keplar_api.models.get_orgs_200_response_items_inner_default_workspace.getOrgs_200_response_items_inner_defaultWorkspace(
                    id = '', 
                    name = '', ),
                stats = keplar_api.models.get_orgs_200_response_items_inner_stats.getOrgs_200_response_items_inner_stats(
                    total_projects = 1.337, 
                    total_responses_completed = 1.337, 
                    total_responses = 1.337, 
                    total_members = 1.337, 
                    last_activity_at = '', ),
                created_at = '',
                updated_at = '',
        )
        """

    def testGetOrgs200ResponseItemsInner(self):
        """Test GetOrgs200ResponseItemsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.call_summary import CallSummary

class TestCallSummary(unittest.TestCase):
    """CallSummary unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CallSummary:
        """Test CallSummary
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CallSummary`
        """
        model = CallSummary()
        if include_optional:
            return CallSummary(
                id = '',
                status = 'REQUESTED',
                metadata = keplar_api.models.call_metadata.CallMetadata(
                    recording_url = '', 
                    transcript = '', 
                    transcript_quality = 'HIGH', 
                    transcript_markdown = '', 
                    transcript_insight = '', 
                    analysis = keplar_api.models.call_analysis.CallAnalysis(
                        summary = '', 
                        success_evaluation = '', ), 
                    gcs_url = '', 
                    gcs_path = '', 
                    gcs_uploaded_at = '', 
                    gcs_last_synced_at = '', 
                    video_recording_url = '', 
                    video_gcs_url = '', 
                    video_gcs_path = '', 
                    video_uploaded_at = '', 
                    video_mime_type = '', 
                    video_duration_seconds = 1.337, 
                    video_size_bytes = 1.337, 
                    video_recording_status = 'recording', 
                    video_recording_error = '', ),
                duration_ms = 56
            )
        else:
            return CallSummary(
                id = '',
                status = 'REQUESTED',
                metadata = keplar_api.models.call_metadata.CallMetadata(
                    recording_url = '', 
                    transcript = '', 
                    transcript_quality = 'HIGH', 
                    transcript_markdown = '', 
                    transcript_insight = '', 
                    analysis = keplar_api.models.call_analysis.CallAnalysis(
                        summary = '', 
                        success_evaluation = '', ), 
                    gcs_url = '', 
                    gcs_path = '', 
                    gcs_uploaded_at = '', 
                    gcs_last_synced_at = '', 
                    video_recording_url = '', 
                    video_gcs_url = '', 
                    video_gcs_path = '', 
                    video_uploaded_at = '', 
                    video_mime_type = '', 
                    video_duration_seconds = 1.337, 
                    video_size_bytes = 1.337, 
                    video_recording_status = 'recording', 
                    video_recording_error = '', ),
                duration_ms = 56,
        )
        """

    def testCallSummary(self):
        """Test CallSummary"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.api_invites_id_participant_invites_post_request_participant import ApiInvitesIdParticipantInvitesPostRequestParticipant

class TestApiInvitesIdParticipantInvitesPostRequestParticipant(unittest.TestCase):
    """ApiInvitesIdParticipantInvitesPostRequestParticipant unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiInvitesIdParticipantInvitesPostRequestParticipant:
        """Test ApiInvitesIdParticipantInvitesPostRequestParticipant
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiInvitesIdParticipantInvitesPostRequestParticipant`
        """
        model = ApiInvitesIdParticipantInvitesPostRequestParticipant()
        if include_optional:
            return ApiInvitesIdParticipantInvitesPostRequestParticipant(
                id = '',
                name = '',
                email = '',
                phone_number = '01234',
                config = keplar_api.models.participant_invite_config.ParticipantInviteConfig(
                    send_invite_email = True, 
                    show_call_metadata = True, 
                    is_test_invite = True, )
            )
        else:
            return ApiInvitesIdParticipantInvitesPostRequestParticipant(
        )
        """

    def testApiInvitesIdParticipantInvitesPostRequestParticipant(self):
        """Test ApiInvitesIdParticipantInvitesPostRequestParticipant"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from keplar_api.models.share_entity_config import ShareEntityConfig
from keplar_api.models.share_entity_created_by_kind import ShareEntityCreatedByKind
from keplar_api.models.share_entity_kind import ShareEntityKind
from typing import Optional, Set
from typing_extensions import Self

class ShareEntity(BaseModel):
    """
    ShareEntity
    """ # noqa: E501
    id: StrictStr
    token: StrictStr
    entity_kind: ShareEntityKind = Field(alias="entityKind")
    entity_id: StrictStr = Field(alias="entityId")
    created_at: datetime = Field(alias="createdAt")
    expires_at: Optional[datetime] = Field(default=None, alias="expiresAt")
    access_count: Union[StrictFloat, StrictInt] = Field(alias="accessCount")
    is_active: StrictBool = Field(alias="isActive")
    created_by_kind: Optional[ShareEntityCreatedByKind] = Field(default=None, alias="createdByKind")
    created_by_id: Optional[StrictStr] = Field(default=None, alias="createdById")
    config: ShareEntityConfig
    email_shares: Optional[List[EmailShare]] = Field(default=None, alias="emailShares")
    __properties: ClassVar[List[str]] = ["id", "token", "entityKind", "entityId", "createdAt", "expiresAt", "accessCount", "isActive", "createdByKind", "createdById", "config", "emailShares"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ShareEntity from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of config
        if self.config:
            _dict['config'] = self.config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in email_shares (list)
        _items = []
        if self.email_shares:
            for _item_email_shares in self.email_shares:
                if _item_email_shares:
                    _items.append(_item_email_shares.to_dict())
            _dict['emailShares'] = _items
        # set to None if expires_at (nullable) is None
        # and model_fields_set contains the field
        if self.expires_at is None and "expires_at" in self.model_fields_set:
            _dict['expiresAt'] = None

        # set to None if created_by_kind (nullable) is None
        # and model_fields_set contains the field
        if self.created_by_kind is None and "created_by_kind" in self.model_fields_set:
            _dict['createdByKind'] = None

        # set to None if created_by_id (nullable) is None
        # and model_fields_set contains the field
        if self.created_by_id is None and "created_by_id" in self.model_fields_set:
            _dict['createdById'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ShareEntity from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "token": obj.get("token"),
            "entityKind": obj.get("entityKind"),
            "entityId": obj.get("entityId"),
            "createdAt": obj.get("createdAt"),
            "expiresAt": obj.get("expiresAt"),
            "accessCount": obj.get("accessCount"),
            "isActive": obj.get("isActive"),
            "createdByKind": obj.get("createdByKind"),
            "createdById": obj.get("createdById"),
            "config": ShareEntityConfig.from_dict(obj["config"]) if obj.get("config") is not None else None,
            "emailShares": [EmailShare.from_dict(_item) for _item in obj["emailShares"]] if obj.get("emailShares") is not None else None
        })
        return _obj

from keplar_api.models.email_share import EmailShare
# TODO: Rewrite to not use raise_errors
ShareEntity.model_rebuild(raise_errors=False)




# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.update_notebook_request_config import UpdateNotebookRequestConfig

class TestUpdateNotebookRequestConfig(unittest.TestCase):
    """UpdateNotebookRequestConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateNotebookRequestConfig:
        """Test UpdateNotebookRequestConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateNotebookRequestConfig`
        """
        model = UpdateNotebookRequestConfig()
        if include_optional:
            return UpdateNotebookRequestConfig(
                sources = [
                    ''
                    ],
                mode = 'report',
                settings = None
            )
        else:
            return UpdateNotebookRequestConfig(
                sources = [
                    ''
                    ],
                mode = 'report',
        )
        """

    def testUpdateNotebookRequestConfig(self):
        """Test UpdateNotebookRequestConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.api_demos_create_demo_invite_post_request import ApiDemosCreateDemoInvitePostRequest

class TestApiDemosCreateDemoInvitePostRequest(unittest.TestCase):
    """ApiDemosCreateDemoInvitePostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiDemosCreateDemoInvitePostRequest:
        """Test ApiDemosCreateDemoInvitePostRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiDemosCreateDemoInvitePostRequest`
        """
        model = ApiDemosCreateDemoInvitePostRequest()
        if include_optional:
            return ApiDemosCreateDemoInvitePostRequest(
                name = '',
                company = '',
                email = '',
                invite_code = ''
            )
        else:
            return ApiDemosCreateDemoInvitePostRequest(
                name = '',
                company = '',
                email = '',
                invite_code = '',
        )
        """

    def testApiDemosCreateDemoInvitePostRequest(self):
        """Test ApiDemosCreateDemoInvitePostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.invite_customers_request import InviteCustomersRequest

class TestInviteCustomersRequest(unittest.TestCase):
    """InviteCustomersRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InviteCustomersRequest:
        """Test InviteCustomersRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InviteCustomersRequest`
        """
        model = InviteCustomersRequest()
        if include_optional:
            return InviteCustomersRequest(
                customers = [
                    keplar_api.models.invite_customer_item.InviteCustomerItem(
                        email = '', 
                        name = '0', )
                    ],
                org_name = '0',
                is2_fa_enabled = True,
                default_workspace_id = '',
                create_default_workspace = '0',
                additional_workspace_ids = [
                    ''
                    ]
            )
        else:
            return InviteCustomersRequest(
                customers = [
                    keplar_api.models.invite_customer_item.InviteCustomerItem(
                        email = '', 
                        name = '0', )
                    ],
        )
        """

    def testInviteCustomersRequest(self):
        """Test InviteCustomersRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.artifact_data_search_result_tabs_inner import ArtifactDataSearchResultTabsInner

class TestArtifactDataSearchResultTabsInner(unittest.TestCase):
    """ArtifactDataSearchResultTabsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ArtifactDataSearchResultTabsInner:
        """Test ArtifactDataSearchResultTabsInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ArtifactDataSearchResultTabsInner`
        """
        model = ArtifactDataSearchResultTabsInner()
        if include_optional:
            return ArtifactDataSearchResultTabsInner(
                id = '',
                query = '',
                project_ids = [
                    ''
                    ],
                total_results = 1.337,
                messages = [
                    keplar_api.models.artifact_data_search_result_tabs_inner_messages_inner.ArtifactDataSearchResult_tabs_inner_messages_inner(
                        call_id = '', 
                        project_id = '', 
                        project_name = '', 
                        recording_url = '', 
                        message_index = 1.337, 
                        message = '', 
                        score = 1.337, 
                        context_messages = [
                            keplar_api.models.analyze_notebook_200_response_search_results_messages_inner_context_messages_inner.analyzeNotebook_200_response_searchResults_messages_inner_contextMessages_inner(
                                role = '', 
                                message = '', 
                                index = 1.337, 
                                seconds_from_start = 1.337, 
                                duration = 1.337, )
                            ], )
                    ]
            )
        else:
            return ArtifactDataSearchResultTabsInner(
                id = '',
                query = '',
                project_ids = [
                    ''
                    ],
                total_results = 1.337,
                messages = [
                    keplar_api.models.artifact_data_search_result_tabs_inner_messages_inner.ArtifactDataSearchResult_tabs_inner_messages_inner(
                        call_id = '', 
                        project_id = '', 
                        project_name = '', 
                        recording_url = '', 
                        message_index = 1.337, 
                        message = '', 
                        score = 1.337, 
                        context_messages = [
                            keplar_api.models.analyze_notebook_200_response_search_results_messages_inner_context_messages_inner.analyzeNotebook_200_response_searchResults_messages_inner_contextMessages_inner(
                                role = '', 
                                message = '', 
                                index = 1.337, 
                                seconds_from_start = 1.337, 
                                duration = 1.337, )
                            ], )
                    ],
        )
        """

    def testArtifactDataSearchResultTabsInner(self):
        """Test ArtifactDataSearchResultTabsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.open_ai_model_config import OpenAiModelConfig

class TestOpenAiModelConfig(unittest.TestCase):
    """OpenAiModelConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OpenAiModelConfig:
        """Test OpenAiModelConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OpenAiModelConfig`
        """
        model = OpenAiModelConfig()
        if include_optional:
            return OpenAiModelConfig(
                provider = 'openai',
                model = 'gpt-4.1'
            )
        else:
            return OpenAiModelConfig(
                provider = 'openai',
                model = 'gpt-4.1',
        )
        """

    def testOpenAiModelConfig(self):
        """Test OpenAiModelConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.byo_panel_repdata_config import ByoPanelRepdataConfig

class TestByoPanelRepdataConfig(unittest.TestCase):
    """ByoPanelRepdataConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ByoPanelRepdataConfig:
        """Test ByoPanelRepdataConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ByoPanelRepdataConfig`
        """
        model = ByoPanelRepdataConfig()
        if include_optional:
            return ByoPanelRepdataConfig(
                kind = 'REPDATA',
                selected_qualifications = [
                    keplar_api.models.repdata_qualification.RepdataQualification(
                        question_id = 1.337, 
                        allowed_option_ids = [
                            null
                            ], )
                    ]
            )
        else:
            return ByoPanelRepdataConfig(
                kind = 'REPDATA',
                selected_qualifications = [
                    keplar_api.models.repdata_qualification.RepdataQualification(
                        question_id = 1.337, 
                        allowed_option_ids = [
                            null
                            ], )
                    ],
        )
        """

    def testByoPanelRepdataConfig(self):
        """Test ByoPanelRepdataConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from keplar_api.models.add_user_to_workspace_request import AddUserToWorkspaceRequest
from keplar_api.models.add_workspace_member_request import AddWorkspaceMemberRequest
from keplar_api.models.analyze_notebook200_response import AnalyzeNotebook200Response
from keplar_api.models.analyze_notebook200_response_search_results import AnalyzeNotebook200ResponseSearchResults
from keplar_api.models.analyze_notebook200_response_search_results_messages_inner import AnalyzeNotebook200ResponseSearchResultsMessagesInner
from keplar_api.models.analyze_notebook200_response_search_results_messages_inner_context_messages_inner import AnalyzeNotebook200ResponseSearchResultsMessagesInnerContextMessagesInner
from keplar_api.models.analyze_notebook_request import AnalyzeNotebookRequest
from keplar_api.models.api_demos_create_demo_invite_post_request import ApiDemosCreateDemoInvitePostRequest
from keplar_api.models.api_files_file_id_signed_url_post200_response import ApiFilesFileIdSignedUrlPost200Response
from keplar_api.models.api_files_file_id_signed_url_post_request import ApiFilesFileIdSignedUrlPostRequest
from keplar_api.models.api_invites_id_participant_invites_get200_response import ApiInvitesIdParticipantInvitesGet200Response
from keplar_api.models.api_invites_id_participant_invites_participant_id_put_request import ApiInvitesIdParticipantInvitesParticipantIdPutRequest
from keplar_api.models.api_invites_id_participant_invites_post_request import ApiInvitesIdParticipantInvitesPostRequest
from keplar_api.models.api_invites_id_participant_invites_post_request_participant import ApiInvitesIdParticipantInvitesPostRequestParticipant
from keplar_api.models.api_invites_id_put_request import ApiInvitesIdPutRequest
from keplar_api.models.api_invites_id_responses_post_request import ApiInvitesIdResponsesPostRequest
from keplar_api.models.api_invites_id_responses_response_id_put_request import ApiInvitesIdResponsesResponseIdPutRequest
from keplar_api.models.api_invites_post_request import ApiInvitesPostRequest
from keplar_api.models.api_projects_post_request import ApiProjectsPostRequest
from keplar_api.models.api_projects_post_request_thread_assets_inner import ApiProjectsPostRequestThreadAssetsInner
from keplar_api.models.api_projects_project_id_analysis_post200_response import ApiProjectsProjectIdAnalysisPost200Response
from keplar_api.models.api_projects_project_id_analysis_post_request import ApiProjectsProjectIdAnalysisPostRequest
from keplar_api.models.api_projects_project_id_files_file_id_put_request import ApiProjectsProjectIdFilesFileIdPutRequest
from keplar_api.models.api_projects_project_id_files_get200_response import ApiProjectsProjectIdFilesGet200Response
from keplar_api.models.api_projects_project_id_files_post_request import ApiProjectsProjectIdFilesPostRequest
from keplar_api.models.api_projects_project_id_put_request import ApiProjectsProjectIdPutRequest
from keplar_api.models.api_projects_project_id_search_transcripts_post_request import ApiProjectsProjectIdSearchTranscriptsPostRequest
from keplar_api.models.api_threads_get200_response import ApiThreadsGet200Response
from keplar_api.models.api_threads_thread_id_files_get200_response import ApiThreadsThreadIdFilesGet200Response
from keplar_api.models.api_threads_thread_id_post_request import ApiThreadsThreadIdPostRequest
from keplar_api.models.api_threads_thread_id_project_brief_document_versions_get200_response import ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response
from keplar_api.models.api_threads_thread_id_project_brief_document_versions_version_put200_response import ApiThreadsThreadIdProjectBriefDocumentVersionsVersionPut200Response
from keplar_api.models.api_threads_thread_id_project_brief_versions_get200_response import ApiThreadsThreadIdProjectBriefVersionsGet200Response
from keplar_api.models.artifact import Artifact
from keplar_api.models.artifact_data import ArtifactData
from keplar_api.models.artifact_data_create import ArtifactDataCreate
from keplar_api.models.artifact_data_not_null import ArtifactDataNotNull
from keplar_api.models.artifact_data_presentation import ArtifactDataPresentation
from keplar_api.models.artifact_data_report import ArtifactDataReport
from keplar_api.models.artifact_data_report_projects_inner import ArtifactDataReportProjectsInner
from keplar_api.models.artifact_data_search_result import ArtifactDataSearchResult
from keplar_api.models.artifact_data_search_result_tabs_inner import ArtifactDataSearchResultTabsInner
from keplar_api.models.artifact_data_search_result_tabs_inner_messages_inner import ArtifactDataSearchResultTabsInnerMessagesInner
from keplar_api.models.artifact_data_thematic_analysis import ArtifactDataThematicAnalysis
from keplar_api.models.artifact_data_thematic_analysis_data import ArtifactDataThematicAnalysisData
from keplar_api.models.artifact_data_thematic_analysis_data_themes_inner import ArtifactDataThematicAnalysisDataThemesInner
from keplar_api.models.artifact_kind import ArtifactKind
from keplar_api.models.artifact_metadata import ArtifactMetadata
from keplar_api.models.artifact_version_group import ArtifactVersionGroup
from keplar_api.models.asset_attrs import AssetAttrs
from keplar_api.models.asset_node import AssetNode
from keplar_api.models.attribute import Attribute
from keplar_api.models.attribute_filter_group_schema_inner import AttributeFilterGroupSchemaInner
from keplar_api.models.attribute_kind import AttributeKind
from keplar_api.models.attribute_kind_group import AttributeKindGroup
from keplar_api.models.attribute_kind_group_purpose import AttributeKindGroupPurpose
from keplar_api.models.attribute_kind_group_scope import AttributeKindGroupScope
from keplar_api.models.attribute_stats_schema_inner import AttributeStatsSchemaInner
from keplar_api.models.attribute_stats_schema_inner_group import AttributeStatsSchemaInnerGroup
from keplar_api.models.attribute_stats_schema_inner_kind import AttributeStatsSchemaInnerKind
from keplar_api.models.attribute_stats_schema_inner_values_inner import AttributeStatsSchemaInnerValuesInner
from keplar_api.models.attribute_value_kind import AttributeValueKind
from keplar_api.models.bad_request_error_response import BadRequestErrorResponse
from keplar_api.models.block_content_node import BlockContentNode
from keplar_api.models.blockquote_node import BlockquoteNode
from keplar_api.models.bold_mark import BoldMark
from keplar_api.models.brief_document import BriefDocument
from keplar_api.models.brief_document_version import BriefDocumentVersion
from keplar_api.models.bullet_list_node import BulletListNode
from keplar_api.models.byo_panel_repdata_config import ByoPanelRepdataConfig
from keplar_api.models.call import Call
from keplar_api.models.call_analysis import CallAnalysis
from keplar_api.models.call_event import CallEvent
from keplar_api.models.call_kind import CallKind
from keplar_api.models.call_metadata import CallMetadata
from keplar_api.models.call_status import CallStatus
from keplar_api.models.call_summary import CallSummary
from keplar_api.models.chat_completion_tool import ChatCompletionTool
from keplar_api.models.chat_completion_tool_function import ChatCompletionToolFunction
from keplar_api.models.chat_message import ChatMessage
from keplar_api.models.chat_message_kind import ChatMessageKind
from keplar_api.models.chat_message_role import ChatMessageRole
from keplar_api.models.chat_session import ChatSession
from keplar_api.models.citation import Citation
from keplar_api.models.code_invite import CodeInvite
from keplar_api.models.code_invite_config import CodeInviteConfig
from keplar_api.models.code_invite_config_contacts import CodeInviteConfigContacts
from keplar_api.models.code_invite_config_keplar_panel import CodeInviteConfigKeplarPanel
from keplar_api.models.code_invite_response import CodeInviteResponse
from keplar_api.models.code_mark import CodeMark
from keplar_api.models.content_node import ContentNode
from keplar_api.models.conversation_attrs import ConversationAttrs
from keplar_api.models.conversation_message import ConversationMessage
from keplar_api.models.conversation_message_topic import ConversationMessageTopic
from keplar_api.models.conversation_node import ConversationNode
from keplar_api.models.conversation_step_attrs import ConversationStepAttrs
from keplar_api.models.conversation_step_node import ConversationStepNode
from keplar_api.models.create_artifact_request import CreateArtifactRequest
from keplar_api.models.create_code_invite_response_request import CreateCodeInviteResponseRequest
from keplar_api.models.create_email_share_request import CreateEmailShareRequest
from keplar_api.models.create_notebook_artifact_request import CreateNotebookArtifactRequest
from keplar_api.models.create_notebook_request import CreateNotebookRequest
from keplar_api.models.create_org_request import CreateOrgRequest
from keplar_api.models.create_project_preview_invite201_response import CreateProjectPreviewInvite201Response
from keplar_api.models.create_project_preview_invite_request import CreateProjectPreviewInviteRequest
from keplar_api.models.create_project_share_request import CreateProjectShareRequest
from keplar_api.models.create_project_share_response import CreateProjectShareResponse
from keplar_api.models.create_workspace_request import CreateWorkspaceRequest
from keplar_api.models.delete_artifact200_response import DeleteArtifact200Response
from keplar_api.models.delete_notebook_artifact_version_group200_response import DeleteNotebookArtifactVersionGroup200Response
from keplar_api.models.dummy_user import DummyUser
from keplar_api.models.email_share import EmailShare
from keplar_api.models.evidence import Evidence
from keplar_api.models.feature_config import FeatureConfig
from keplar_api.models.file import File
from keplar_api.models.file_mime_type import FileMimeType
from keplar_api.models.forbidden_error_response import ForbiddenErrorResponse
from keplar_api.models.get_code_invite200_response import GetCodeInvite200Response
from keplar_api.models.get_code_invite_response_redirect200_response import GetCodeInviteResponseRedirect200Response
from keplar_api.models.get_org_members200_response import GetOrgMembers200Response
from keplar_api.models.get_orgs200_response import GetOrgs200Response
from keplar_api.models.get_orgs200_response_items_inner import GetOrgs200ResponseItemsInner
from keplar_api.models.get_orgs200_response_items_inner_default_workspace import GetOrgs200ResponseItemsInnerDefaultWorkspace
from keplar_api.models.get_orgs200_response_items_inner_stats import GetOrgs200ResponseItemsInnerStats
from keplar_api.models.get_project_shares200_response import GetProjectShares200Response
from keplar_api.models.get_projects200_response import GetProjects200Response
from keplar_api.models.get_shared_artifact_version_groups200_response import GetSharedArtifactVersionGroups200Response
from keplar_api.models.get_shared_invite_responses200_response import GetSharedInviteResponses200Response
from keplar_api.models.get_user_workspaces200_response import GetUserWorkspaces200Response
from keplar_api.models.get_workspace_members200_response import GetWorkspaceMembers200Response
from keplar_api.models.get_workspaces200_response import GetWorkspaces200Response
from keplar_api.models.get_workspaces200_response_items_inner import GetWorkspaces200ResponseItemsInner
from keplar_api.models.hard_break_node import HardBreakNode
from keplar_api.models.heading_attrs import HeadingAttrs
from keplar_api.models.heading_node import HeadingNode
from keplar_api.models.impersonate_user200_response import ImpersonateUser200Response
from keplar_api.models.impersonate_user_request import ImpersonateUserRequest
from keplar_api.models.impersonated_user import ImpersonatedUser
from keplar_api.models.inbound_call_response import InboundCallResponse
from keplar_api.models.index_project_transcripts200_response import IndexProjectTranscripts200Response
from keplar_api.models.index_project_transcripts200_response_indexed import IndexProjectTranscripts200ResponseIndexed
from keplar_api.models.inline_node import InlineNode
from keplar_api.models.internal_server_error_response import InternalServerErrorResponse
from keplar_api.models.invite import Invite
from keplar_api.models.invite_config import InviteConfig
from keplar_api.models.invite_config_byo_panel import InviteConfigByoPanel
from keplar_api.models.invite_config_contacts import InviteConfigContacts
from keplar_api.models.invite_config_keplar_panel import InviteConfigKeplarPanel
from keplar_api.models.invite_config_public import InviteConfigPublic
from keplar_api.models.invite_customer_item import InviteCustomerItem
from keplar_api.models.invite_customers201_response import InviteCustomers201Response
from keplar_api.models.invite_customers_request import InviteCustomersRequest
from keplar_api.models.invite_org_result import InviteOrgResult
from keplar_api.models.invite_response import InviteResponse
from keplar_api.models.invite_response_attribute import InviteResponseAttribute
from keplar_api.models.invite_response_attribute_data import InviteResponseAttributeData
from keplar_api.models.invite_response_data import InviteResponseData
from keplar_api.models.invite_response_evaluation_enum import InviteResponseEvaluationEnum
from keplar_api.models.invite_response_evaluation_metadata import InviteResponseEvaluationMetadata
from keplar_api.models.invite_response_kind import InviteResponseKind
from keplar_api.models.invite_response_metadata import InviteResponseMetadata
from keplar_api.models.invite_response_share_config import InviteResponseShareConfig
from keplar_api.models.invite_response_status import InviteResponseStatus
from keplar_api.models.invite_response_update_event import InviteResponseUpdateEvent
from keplar_api.models.invite_response_with_call_summary import InviteResponseWithCallSummary
from keplar_api.models.invite_response_with_metadata import InviteResponseWithMetadata
from keplar_api.models.invite_response_with_metadata_attributes_inner import InviteResponseWithMetadataAttributesInner
from keplar_api.models.invite_response_with_metadata_attributes_inner_evidence import InviteResponseWithMetadataAttributesInnerEvidence
from keplar_api.models.invite_status import InviteStatus
from keplar_api.models.invite_user_request import InviteUserRequest
from keplar_api.models.invite_with_analytics import InviteWithAnalytics
from keplar_api.models.invite_workspace_result import InviteWorkspaceResult
from keplar_api.models.invited_user import InvitedUser
from keplar_api.models.italic_mark import ItalicMark
from keplar_api.models.join_code_invite302_response import JoinCodeInvite302Response
from keplar_api.models.join_code_invite302_response_settings import JoinCodeInvite302ResponseSettings
from keplar_api.models.link_mark import LinkMark
from keplar_api.models.link_mark_attrs import LinkMarkAttrs
from keplar_api.models.list_item_node import ListItemNode
from keplar_api.models.login200_response import Login200Response
from keplar_api.models.login200_response_any_of import Login200ResponseAnyOf
from keplar_api.models.login400_response import Login400Response
from keplar_api.models.login400_response_any_of import Login400ResponseAnyOf
from keplar_api.models.login_request import LoginRequest
from keplar_api.models.mark import Mark
from keplar_api.models.mention_node import MentionNode
from keplar_api.models.mention_node_attrs import MentionNodeAttrs
from keplar_api.models.moderator import Moderator
from keplar_api.models.moderator_vendor import ModeratorVendor
from keplar_api.models.moderator_visibility import ModeratorVisibility
from keplar_api.models.not_found_error_response import NotFoundErrorResponse
from keplar_api.models.notebook import Notebook
from keplar_api.models.notebook_artifact_version_group import NotebookArtifactVersionGroup
from keplar_api.models.notebook_artifact_version_group_metadata import NotebookArtifactVersionGroupMetadata
from keplar_api.models.notebook_artifact_version_group_visibility import NotebookArtifactVersionGroupVisibility
from keplar_api.models.notebook_config import NotebookConfig
from keplar_api.models.notebook_mode import NotebookMode
from keplar_api.models.number_filter_schema import NumberFilterSchema
from keplar_api.models.open_ai_model_config import OpenAiModelConfig
from keplar_api.models.option_kind import OptionKind
from keplar_api.models.ordered_list_attrs import OrderedListAttrs
from keplar_api.models.ordered_list_node import OrderedListNode
from keplar_api.models.org import Org
from keplar_api.models.org_data import OrgData
from keplar_api.models.org_default_workspace import OrgDefaultWorkspace
from keplar_api.models.org_list_item import OrgListItem
from keplar_api.models.org_member import OrgMember
from keplar_api.models.org_stats import OrgStats
from keplar_api.models.panel_qualification import PanelQualification
from keplar_api.models.panel_respondent_attribute import PanelRespondentAttribute
from keplar_api.models.panel_settings import PanelSettings
from keplar_api.models.paragraph_node import ParagraphNode
from keplar_api.models.participant import Participant
from keplar_api.models.participant_attribute import ParticipantAttribute
from keplar_api.models.participant_create import ParticipantCreate
from keplar_api.models.participant_invite import ParticipantInvite
from keplar_api.models.participant_invite_config import ParticipantInviteConfig
from keplar_api.models.participant_invite_data import ParticipantInviteData
from keplar_api.models.phone_call_start_response import PhoneCallStartResponse
from keplar_api.models.presentation_config import PresentationConfig
from keplar_api.models.presentation_config1 import PresentationConfig1
from keplar_api.models.project import Project
from keplar_api.models.project_analysis import ProjectAnalysis
from keplar_api.models.project_analysis_report import ProjectAnalysisReport
from keplar_api.models.project_audience import ProjectAudience
from keplar_api.models.project_brief import ProjectBrief
from keplar_api.models.project_config import ProjectConfig
from keplar_api.models.project_conversation_config import ProjectConversationConfig
from keplar_api.models.project_file import ProjectFile
from keplar_api.models.project_file_category import ProjectFileCategory
from keplar_api.models.project_file_metadata import ProjectFileMetadata
from keplar_api.models.project_file_public import ProjectFilePublic
from keplar_api.models.project_file_public_file import ProjectFilePublicFile
from keplar_api.models.project_kind import ProjectKind
from keplar_api.models.project_share_config import ProjectShareConfig
from keplar_api.models.project_status import ProjectStatus
from keplar_api.models.project_summary_with_analytics import ProjectSummaryWithAnalytics
from keplar_api.models.project_with_analytics import ProjectWithAnalytics
from keplar_api.models.remaining_responses_response import RemainingResponsesResponse
from keplar_api.models.repdata_qualification import RepdataQualification
from keplar_api.models.repdata_qualification_allowed_option_ids_inner import RepdataQualificationAllowedOptionIdsInner
from keplar_api.models.repdata_respondent_attribute import RepdataRespondentAttribute
from keplar_api.models.repdata_survey import RepdataSurvey
from keplar_api.models.repdata_survey_attributes import RepdataSurveyAttributes
from keplar_api.models.repdata_survey_redirects import RepdataSurveyRedirects
from keplar_api.models.report import Report
from keplar_api.models.request_share_access200_response import RequestShareAccess200Response
from keplar_api.models.request_share_access_request import RequestShareAccessRequest
from keplar_api.models.reset_password_request import ResetPasswordRequest
from keplar_api.models.response_call_completed_event import ResponseCallCompletedEvent
from keplar_api.models.response_call_failed_event import ResponseCallFailedEvent
from keplar_api.models.response_consent_event import ResponseConsentEvent
from keplar_api.models.response_opt_out_event import ResponseOptOutEvent
from keplar_api.models.response_processing_completed_event import ResponseProcessingCompletedEvent
from keplar_api.models.response_processing_failed_event import ResponseProcessingFailedEvent
from keplar_api.models.response_redirect_event import ResponseRedirectEvent
from keplar_api.models.response_start_call_event import ResponseStartCallEvent
from keplar_api.models.response_submit_email_event import ResponseSubmitEmailEvent
from keplar_api.models.response_submit_screener_event import ResponseSubmitScreenerEvent
from keplar_api.models.save_search_request import SaveSearchRequest
from keplar_api.models.save_search_request_tabs_inner import SaveSearchRequestTabsInner
from keplar_api.models.screener_question import ScreenerQuestion
from keplar_api.models.screener_question_choose_multiple import ScreenerQuestionChooseMultiple
from keplar_api.models.screener_question_choose_multiple_options_value import ScreenerQuestionChooseMultipleOptionsValue
from keplar_api.models.screener_question_choose_multiple_public import ScreenerQuestionChooseMultiplePublic
from keplar_api.models.screener_question_choose_one import ScreenerQuestionChooseOne
from keplar_api.models.screener_question_choose_one_public import ScreenerQuestionChooseOnePublic
from keplar_api.models.screener_question_option import ScreenerQuestionOption
from keplar_api.models.screener_question_public import ScreenerQuestionPublic
from keplar_api.models.screener_question_response import ScreenerQuestionResponse
from keplar_api.models.search_project_transcripts_response import SearchProjectTranscriptsResponse
from keplar_api.models.search_shared_response_messages200_response_inner import SearchSharedResponseMessages200ResponseInner
from keplar_api.models.search_shared_response_messages_request import SearchSharedResponseMessagesRequest
from keplar_api.models.search_shared_response_messages_request_invite_response_messages_inner import SearchSharedResponseMessagesRequestInviteResponseMessagesInner
from keplar_api.models.search_users200_response import SearchUsers200Response
from keplar_api.models.search_users_request import SearchUsersRequest
from keplar_api.models.select_filter_schema import SelectFilterSchema
from keplar_api.models.share_entity import ShareEntity
from keplar_api.models.share_entity_config import ShareEntityConfig
from keplar_api.models.share_entity_created_by_kind import ShareEntityCreatedByKind
from keplar_api.models.share_entity_kind import ShareEntityKind
from keplar_api.models.signup_request import SignupRequest
from keplar_api.models.skipped_customer import SkippedCustomer
from keplar_api.models.start_phone_call_for_code_invite_response_request import StartPhoneCallForCodeInviteResponseRequest
from keplar_api.models.supported_language import SupportedLanguage
from keplar_api.models.text_node import TextNode
from keplar_api.models.thematic_analysis_artifact_create_data import ThematicAnalysisArtifactCreateData
from keplar_api.models.thematic_analysis_artifact_create_data_themes_inner import ThematicAnalysisArtifactCreateDataThemesInner
from keplar_api.models.thematic_analysis_artifact_create_data_themes_inner_codes_inner import ThematicAnalysisArtifactCreateDataThemesInnerCodesInner
from keplar_api.models.thematic_analysis_response_code import ThematicAnalysisResponseCode
from keplar_api.models.thematic_analysis_response_code_codes_inner import ThematicAnalysisResponseCodeCodesInner
from keplar_api.models.thematic_analysis_response_code_codes_inner_evidence import ThematicAnalysisResponseCodeCodesInnerEvidence
from keplar_api.models.thread import Thread
from keplar_api.models.thread_create_project_status import ThreadCreateProjectStatus
from keplar_api.models.thread_file import ThreadFile
from keplar_api.models.thread_kind import ThreadKind
from keplar_api.models.thread_metadata import ThreadMetadata
from keplar_api.models.token_kind import TokenKind
from keplar_api.models.transcript import Transcript
from keplar_api.models.transcript_attributes_inner import TranscriptAttributesInner
from keplar_api.models.transcript_message import TranscriptMessage
from keplar_api.models.transcript_messages_inner import TranscriptMessagesInner
from keplar_api.models.transcript_quality import TranscriptQuality
from keplar_api.models.transcript_response_attribute import TranscriptResponseAttribute
from keplar_api.models.unauthorized_error_response import UnauthorizedErrorResponse
from keplar_api.models.update_artifact_request import UpdateArtifactRequest
from keplar_api.models.update_call_for_code_invite_response_request import UpdateCallForCodeInviteResponseRequest
from keplar_api.models.update_call_for_code_invite_response_request_call import UpdateCallForCodeInviteResponseRequestCall
from keplar_api.models.update_code_invite_response404_response import UpdateCodeInviteResponse404Response
from keplar_api.models.update_notebook_request import UpdateNotebookRequest
from keplar_api.models.update_notebook_request_config import UpdateNotebookRequestConfig
from keplar_api.models.update_notebook_sources_request import UpdateNotebookSourcesRequest
from keplar_api.models.update_org2_fa_request import UpdateOrg2FARequest
from keplar_api.models.update_org_default_workspace_request import UpdateOrgDefaultWorkspaceRequest
from keplar_api.models.update_search_request import UpdateSearchRequest
from keplar_api.models.update_share_entity_request import UpdateShareEntityRequest
from keplar_api.models.update_user_default_workspace200_response import UpdateUserDefaultWorkspace200Response
from keplar_api.models.update_user_default_workspace_request import UpdateUserDefaultWorkspaceRequest
from keplar_api.models.update_workspace_member_request import UpdateWorkspaceMemberRequest
from keplar_api.models.upload_call_video_response import UploadCallVideoResponse
from keplar_api.models.user import User
from keplar_api.models.user_account_status import UserAccountStatus
from keplar_api.models.user_admin_level import UserAdminLevel
from keplar_api.models.user_data import UserData
from keplar_api.models.user_default_workspace import UserDefaultWorkspace
from keplar_api.models.user_org import UserOrg
from keplar_api.models.user_project import UserProject
from keplar_api.models.user_provider import UserProvider
from keplar_api.models.user_search_result import UserSearchResult
from keplar_api.models.user_with_config import UserWithConfig
from keplar_api.models.user_workspace_item import UserWorkspaceItem
from keplar_api.models.vapi_assistant_config import VapiAssistantConfig
from keplar_api.models.vapi_voice_id import VapiVoiceId
from keplar_api.models.vapi_voice_vapi_provider import VapiVoiceVapiProvider
from keplar_api.models.verify_email_access_for_share200_response import VerifyEmailAccessForShare200Response
from keplar_api.models.verify_email_access_for_share_request import VerifyEmailAccessForShareRequest
from keplar_api.models.verify_email_request import VerifyEmailRequest
from keplar_api.models.video_recording_settings import VideoRecordingSettings
from keplar_api.models.video_recording_status import VideoRecordingStatus
from keplar_api.models.workspace import Workspace
from keplar_api.models.workspace_list_item import WorkspaceListItem
from keplar_api.models.workspace_member import WorkspaceMember
from keplar_api.models.workspace_member_item import WorkspaceMemberItem
from keplar_api.models.workspace_member_response import WorkspaceMemberResponse
from keplar_api.models.workspace_member_role import WorkspaceMemberRole
from keplar_api.models.workspace_member_user import WorkspaceMemberUser




# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.user_account_status import UserAccountStatus
from keplar_api.models.user_default_workspace import UserDefaultWorkspace
from keplar_api.models.user_org import UserOrg
from keplar_api.models.user_project import UserProject
from typing import Optional, Set
from typing_extensions import Self

class UserSearchResult(BaseModel):
    """
    UserSearchResult
    """ # noqa: E501
    id: StrictStr
    email: StrictStr
    name: StrictStr
    account_status: UserAccountStatus = Field(alias="accountStatus")
    data: Optional[Any]
    org_id: Optional[StrictStr] = Field(alias="orgId")
    org: Optional[UserOrg]
    projects: List[UserProject]
    default_workspace: Optional[UserDefaultWorkspace] = Field(alias="defaultWorkspace")
    created_at: StrictStr = Field(alias="createdAt")
    __properties: ClassVar[List[str]] = ["id", "email", "name", "accountStatus", "data", "orgId", "org", "projects", "defaultWorkspace", "createdAt"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserSearchResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of org
        if self.org:
            _dict['org'] = self.org.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in projects (list)
        _items = []
        if self.projects:
            for _item_projects in self.projects:
                if _item_projects:
                    _items.append(_item_projects.to_dict())
            _dict['projects'] = _items
        # override the default output from pydantic by calling `to_dict()` of default_workspace
        if self.default_workspace:
            _dict['defaultWorkspace'] = self.default_workspace.to_dict()
        # set to None if data (nullable) is None
        # and model_fields_set contains the field
        if self.data is None and "data" in self.model_fields_set:
            _dict['data'] = None

        # set to None if org_id (nullable) is None
        # and model_fields_set contains the field
        if self.org_id is None and "org_id" in self.model_fields_set:
            _dict['orgId'] = None

        # set to None if org (nullable) is None
        # and model_fields_set contains the field
        if self.org is None and "org" in self.model_fields_set:
            _dict['org'] = None

        # set to None if default_workspace (nullable) is None
        # and model_fields_set contains the field
        if self.default_workspace is None and "default_workspace" in self.model_fields_set:
            _dict['defaultWorkspace'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserSearchResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "email": obj.get("email"),
            "name": obj.get("name"),
            "accountStatus": obj.get("accountStatus"),
            "data": obj.get("data"),
            "orgId": obj.get("orgId"),
            "org": UserOrg.from_dict(obj["org"]) if obj.get("org") is not None else None,
            "projects": [UserProject.from_dict(_item) for _item in obj["projects"]] if obj.get("projects") is not None else None,
            "defaultWorkspace": UserDefaultWorkspace.from_dict(obj["defaultWorkspace"]) if obj.get("defaultWorkspace") is not None else None,
            "createdAt": obj.get("createdAt")
        })
        return _obj


